HilbertEOFRotator
=================

.. currentmodule:: xeofs.single

.. autoclass:: HilbertEOFRotator
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HilbertEOFRotator.__init__
      ~HilbertEOFRotator.components
      ~HilbertEOFRotator.components_amplitude
      ~HilbertEOFRotator.components_phase
      ~HilbertEOFRotator.compute
      ~HilbertEOFRotator.deserialize
      ~HilbertEOFRotator.explained_variance
      ~HilbertEOFRotator.explained_variance_ratio
      ~HilbertEOFRotator.fit
      ~HilbertEOFRotator.fit_transform
      ~HilbertEOFRotator.get_params
      ~HilbertEOFRotator.get_serialization_attrs
      ~HilbertEOFRotator.inverse_transform
      ~HilbertEOFRotator.load
      ~HilbertEOFRotator.save
      ~HilbertEOFRotator.scores
      ~HilbertEOFRotator.scores_amplitude
      ~HilbertEOFRotator.scores_phase
      ~HilbertEOFRotator.serialize
      ~HilbertEOFRotator.singular_values
      ~HilbertEOFRotator.transform
   
   

   
   
   